<?php

/**
 * JCH Optimize - Performs several front-end optimizations for fast downloads.
 *
 * @author    Samuel Marshall <samuel@jch-optimize.net>
 * @copyright Copyright (c) 2023 Samuel Marshall / JCH Optimize
 * @license   GNU/GPLv3, or later. See LICENSE file
 *
 *  If LICENSE file missing, see <http://www.gnu.org/licenses/>.
 */

namespace JchOptimize\Core\Html;

use _JchOptimizeVendor\Psr\Http\Message\UriInterface;

class Attribute
{
    private string $name;

    /**
     * @var array|string|UriInterface
     */
    private $value;
    private string $delimiter = '"';
    private bool $boolean = \false;

    /**
     * @return $this|string
     */
    public function name(?string $name = null)
    {
        if (null === $name) {
            return $this->name;
        }
        $this->name = $name;

        return $this;
    }

    /**
     * @param null|array|string|UriInterface $value
     *
     * @return $this|string
     */
    public function value($value = null)
    {
        if (null === $value) {
            if ($this->boolean()) {
                return \true;
            }

            return $this->value;
        }
        $this->value = $value;

        return $this;
    }

    /**
     * @return $this|string
     */
    public function delimiter(?string $delimiter = null)
    {
        if (null === $delimiter) {
            return $this->delimiter;
        }
        $this->delimiter = $delimiter;

        return $this;
    }

    /**
     * @return $this|bool
     */
    public function boolean(?bool $boolean = null)
    {
        if (null === $boolean) {
            return $this->boolean;
        }
        $this->boolean = $boolean;

        return $this;
    }
}
