<?php

/**
 * JCH Optimize - Performs several front-end optimizations for fast downloads.
 *
 * @author    Samuel Marshall <samuel@jch-optimize.net>
 * @copyright Copyright (c) 2023 Samuel Marshall / JCH Optimize
 * @license   GNU/GPLv3, or later. See LICENSE file
 *
 *  If LICENSE file missing, see <http://www.gnu.org/licenses/>.
 */

namespace JchOptimize\Core\Html;

use JchOptimize\Core\Exception\PregErrorException;
use JchOptimize\Core\Html\Callbacks\BuildHtmlElement;
use JchOptimize\Core\Html\Elements\BaseElement;
use JchOptimize\Core\Html\Elements\Img;
use JchOptimize\Core\Html\Elements\Link;
use JchOptimize\Core\Html\Elements\Script;
use JchOptimize\Core\Html\Elements\Style;

/**
 * @method static Link   link()
 * @method static Script script()
 * @method static Style  style()
 * @method static Img    img()
 */
class HtmlElementBuilder
{
    public static function __callStatic($name, $arguments)
    {
        $class = '\\JchOptimize\\Core\\Html\\Elements\\'.\ucfirst($name);
        if (\class_exists($class)) {
            return new $class();
        }
        $element = new BaseElement();
        $element->setName($name);

        return $element;
    }

    /**
     * @throws PregErrorException
     */
    public static function load(string $html): HtmlElementInterface
    {
        $parser = new \JchOptimize\Core\Html\Parser();
        $parser->addExclude(\JchOptimize\Core\Html\Parser::htmlCommentToken());
        $elementObj = new \JchOptimize\Core\Html\ElementObject();
        $elementObj->bCaptureAttributes = \true;
        $elementObj->bSelfClosing = null;
        $elementObj->bCaptureContent = \true;
        $elementObj->bParseContentLazily = \false;
        $parser->addElementObject($elementObj);
        $callback = new BuildHtmlElement();
        $parser->processMatchesWithCallback($html, $callback);

        return $callback->getElement();
    }
}
